@@ -14,7 +14,7 @@ use parent qw( Archive::Libarchive::Archive );
 use constant;
 
 # ABSTRACT: Libarchive read archive class
-our $VERSION = '0.06'; # VERSION
+our $VERSION = '0.07'; # VERSION
 
 my $ffi = Archive::Libarchive::Lib->ffi;
 constant->import(_opaque_size => $ffi->sizeof('opaque'));
@@ -201,7 +201,7 @@ Archive::Libarchive::ArchiveRead - Libarchive read archive class
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 SYNOPSIS
 
@@ -327,6 +327,13 @@ This takes either a L<FFI::C::File>, or an opaque pointer to a libc file pointer
 
 This takes a perl file handle and reads the archive from there.
 
+=head2 open_filename
+
+ # archive_read_open_filename
+ my $int = $r->open_filename($string, $size_t);
+
+Open a single-file archive.  The C<$size_t> argument is the block size.
+
 =head2 open_filenames
 
  # archive_read_open_filenames
